.. currentmodule:: pyfits

.. _tables:

******
Tables
******

.. inheritance-diagram:: Column ColDefs FITS_record FITS_rec GroupData TableHDU BinTableHDU

`BinTableHDU`
=============

.. autoclass:: BinTableHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`TableHDU`
==========

.. autoclass:: TableHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`Column`
========

.. autoclass:: Column
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`ColDefs`
=========

.. autoclass:: ColDefs
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`FITS_record`
=============

.. autoclass:: FITS_record
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`FITS_rec`
==========

.. autoclass:: FITS_rec
   :members:
   :undoc-members:
   :show-inheritance:

`GroupData`
===========

.. autoclass:: GroupData
   :members:
   :undoc-members:
   :show-inheritance:


Free functions
==============

new_table
---------

.. autofunction:: new_table

tdump
-----

.. autofunction:: tdump

tcreate
-------

.. autofunction:: tcreate
